Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(142)

Unified Diff: Source/core/workers/SharedWorkerGlobalScope.h

Issue 17648006: Rename WorkerContext to WorkerGlobalScope (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Rebase on master Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/workers/SharedWorkerContext.idl ('k') | Source/core/workers/SharedWorkerGlobalScope.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/workers/SharedWorkerGlobalScope.h
diff --git a/Source/core/workers/SharedWorkerContext.h b/Source/core/workers/SharedWorkerGlobalScope.h
similarity index 73%
rename from Source/core/workers/SharedWorkerContext.h
rename to Source/core/workers/SharedWorkerGlobalScope.h
index b87f849da788690c8e891e0771b0e1034b90e3d0..1d4a48ff7048198260b7c2843587debe0022089e 100644
--- a/Source/core/workers/SharedWorkerContext.h
+++ b/Source/core/workers/SharedWorkerGlobalScope.h
@@ -28,36 +28,36 @@
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
-#ifndef SharedWorkerContext_h
-#define SharedWorkerContext_h
+#ifndef SharedWorkerGlobalScope_h
+#define SharedWorkerGlobalScope_h
#include "core/page/ContentSecurityPolicy.h"
-#include "core/workers/WorkerContext.h"
+#include "core/workers/WorkerGlobalScope.h"
namespace WebCore {
class MessageEvent;
class SharedWorkerThread;
- class SharedWorkerContext : public WorkerContext {
+ class SharedWorkerGlobalScope : public WorkerGlobalScope {
public:
- typedef WorkerContext Base;
- static PassRefPtr<SharedWorkerContext> create(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*, const String& contentSecurityPolicy, ContentSecurityPolicy::HeaderType contentSecurityPolicyType);
- virtual ~SharedWorkerContext();
+ typedef WorkerGlobalScope Base;
+ static PassRefPtr<SharedWorkerGlobalScope> create(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*, const String& contentSecurityPolicy, ContentSecurityPolicy::HeaderType contentSecurityPolicyType);
+ virtual ~SharedWorkerGlobalScope();
- virtual bool isSharedWorkerContext() const OVERRIDE { return true; }
+ virtual bool isSharedWorkerGlobalScope() const OVERRIDE { return true; }
// EventTarget
virtual const AtomicString& interfaceName() const OVERRIDE;
// Setters/Getters for attributes in SharedWorkerContext.idl
DEFINE_ATTRIBUTE_EVENT_LISTENER(connect);
String name() const { return m_name; }
SharedWorkerThread* thread();
private:
- SharedWorkerContext(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*);
+ SharedWorkerGlobalScope(const String& name, const KURL&, const String& userAgent, SharedWorkerThread*);
virtual void logExceptionToConsole(const String& errorMessage, const String& sourceURL, int lineNumber, PassRefPtr<ScriptCallStack>) OVERRIDE;
String m_name;
@@ -67,4 +67,4 @@ namespace WebCore {
} // namespace WebCore
-#endif // SharedWorkerContext_h
+#endif // SharedWorkerGlobalScope_h
« no previous file with comments | « Source/core/workers/SharedWorkerContext.idl ('k') | Source/core/workers/SharedWorkerGlobalScope.cpp » ('j') | no next file with comments »

Powered by Google App Engine
@@ -28,36 +28,36 @@
// EventTarget
virtual const AtomicString& interfaceName() const OVERRIDE;
- // Setters/Getters for attributes in SharedWorkerContext.idl
+ // Setters/Getters for attributes in SharedWorkerGlobalScope.idl
DEFINE_ATTRIBUTE_EVENT_LISTENER(connect);
String name() const { return m_name; }
This is Rietveld 408576698